note
	description: "Summary description for {WEATHER_DATA}."
	author: "Jonathan S. Ostroff and Jackie Wang"
	date: "$Date$"
	revision: "$Revision$"

class
	WEATHER_DATA

create
	make

feature -- weather data available to observers

	temperature: REAL
	humidity: REAL
	pressure: REAL

	correct_limits(t, p, h: REAL): BOOLEAN
			-- Are temperature 't', pressure 'p', and humidity 'h' legal?
		do
			if -36 <= t and t <= 60
				and 50 <= p and p <= 110 -- kPa
				and 0.8 <= h and h <= 100 -- %R
			then
				Result := true
			end
		ensure
			-- temperature in centigrade
			Result implies -36 <=t and t <= 60
			-- pressure in kPA
			Result implies 50 <= p and p <= 110
			-- humidity in %RH
			Result implies 0.8 <= h and h <= 100
		end

feature -- Initialization
	make (t, p, h: REAL)
			-- Initialize weather data.
		do
			set_measurements (t, p, h)
		ensure then
			temperature = t
			pressure = p
			humidity = h
		end

feature  -- weather station interface
	set_measurements(t, p, h: REAL)
			-- Change the data.
		require
			correct_limits(t,p,h)
		do
			temperature := t
			humidity := h
			pressure := p
		ensure
			temperature = t
			pressure = p
			humidity = h
		end

invariant
	correct_limits(temperature, pressure, humidity)

end
